==> Tagz-1.0.0.zip: Tagz/lang/oc.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Mots cles',
 'L_TITLE'=>'Editer suls mots cles du ensièr',
 'L_DESCRIPTION'=>'gerer suls tags du ensièr delir ou renommer l’ensembsuls vacairòls mots cles.',
#admin
 'L_CANCEL'=>'membre annuler',
 'L_DEVIENT'=>'devient',
 'L_POUR'=>'grèu',
 'L_SEARCH'=>'requistar trabucar suls articsuls femna ce diccion cle',
 'L_RESTORE'=>'retablir',
 'L_DEL'=>'Effacer',
 'L_RESTORE_ALL'=>'retablir totes suls Aliscamps laisses vides',
 'L_DEL_ALL'=>'Effacer totes suls Aliscamps',
 'L_ART_NUM'=>'grèu suls articsuls femna suls numero(s)',
 'L_HELP_TAG_FIELD'=>'Si le semenat ostalat vide, aquò supprime le diccion cle apres téner registrar'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'Rafraichir',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Fichier tags.xml rafraichis per suls mots cles vacairòls articsuls',
 'L_TAG_PLACEHOLDER'=>'supprime si daissar vuèja',
 'L_DEDUPLICATED'=>'dedoublonne',
 'L_IN_REALITY'=>'En realite',
 'L_IS_UNIK'=>'Uniques (est solo)',
 'L_DOUBLES'=>'Doubles',
 'L_TRIPLES'=>'Triples',
 'L_QUADRUPLES'=>'Quadruples',
 'L_QUINTUPLES'=>'Quintuples',
 'L_SEXTUPLES'=>'Sextuples',
 'L_SEPTUPLES'=>'Septuples',
#config
 'L_ACCES'=>'Type(s) de mainar autorise(s) a acceder au plugin',
 'L_HELP_ACCES'=>'unes son suls perfial autorises a sosamenar le plugin. tièra seperes per vacairòls virgusuls &nbsp;&nbsp; defaut : PROFIL_ADMIN, &nbsp;&nbsp;',
 'L_DENY'=>'Utilisateur(s) interdit d’acces au plugin (Menu caché)',
 'L_HELP_DENY'=>'Quels sont les identifiants des utilisateur a qui il est interdit d’utiliser le plugin. Liste séparés par des virgules (Par exemple : 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/oc.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Mots cles',
 'L_TITLE'=>'Editer suls mots cles du ensièr',
 'L_DESCRIPTION'=>'gerer suls tags du ensièr delir ou renommer l’ensembsuls vacairòls mots cles.',
 'L_FILTER_TAGS'=>'colar suls mots cles',
 'L_FILTER_TAGS_PH'=>'col vacairòls mots',
 'L_CANCEL'=>'Tout annuler',
 'L_DEVIENT'=>'devient',
 'L_POUR'=>'grèu',
 'L_SEARCH'=>'requistar trabucar suls articsuls femna ce diccion cle',
 'L_RESTORE'=>'retablir',
 'L_DEL'=>'Effacer',
 'L_RESTORE_ALL'=>'retablir totes suls Aliscamps laisses vides',
 'L_DEL_ALL'=>'Effacer totes suls Aliscamps',
 'L_ART_NUM'=>'grèu suls articsuls femna suls numero(s)',
 'L_HELP_TAG_FIELD'=>'Si le semenat ostalat vide, aquò supprime le diccion cle apres téner registrar',
 'L_HELP_TAG_CTRLZ'=>'de combinaison de tocada Ctrl + z permet d annuler',
 'L_TAGS_REFRESH'=>'Rafraichir',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Fichier tags.xml rafraichis per suls mots cles vacairòls articsuls',
 'L_TAG_PLACEHOLDER'=>'supprime si daissar vuèja',
 'L_DEDUPLICATED'=>'dedoublonne',
 'L_IN_REALITY'=>'En realite',
 'L_IS_UNIK'=>'Uniques (est solo)',
 'L_DOUBLES'=>'Doubles',
 'L_TRIPLES'=>'Triples',
 'L_QUADRUPLES'=>'Quadruples',
 'L_QUINTUPLES'=>'Quintuples',
 'L_SEXTUPLES'=>'Sextuples',
 'L_SEPTUPLES'=>'Septuples',
 'L_OCTUPLES'=>'Octuples',
 'L_NONUPLES'=>'Nonuples',
 'L_DECUPLES'=>'Decuples',
#config
 'L_ACCES'=>'Type(s) de mainar autorise(s) a acceder au plugin',
 'L_HELP_ACCES'=>'unes son suls perfial autorises a sosamenar le plugin. tièra seperes per vacairòls virgusuls &nbsp;&nbsp; defaut : PROFIL_ADMIN, &nbsp;&nbsp;',
 'L_DENY'=>'Utilisateur(s) interdit d’acces au plugin (Menu caché)',
 'L_HELP_DENY'=>'Quels sont les identifiants des utilisateur a qui il est interdit d’utiliser le plugin. Liste séparés par des virgules (Par exemple : 001,002,007).',
);
?>
